import { getUserMedia } from "./utils.js";
class AudioRecorder {
  constructor(options = {}) {
    this.options = options;
  }
  static async listDevices() {
    return navigator.mediaDevices.enumerateDevices().then((list) => list.filter((d) => d.kind === "audioinput"));
  }
  context;
  listeners = {};
  buffer = [];
  recorder;
  stream;
  async start(deviceId) {
    this.recorder = await this.createAudioRecorder();
    this.recorder.start();
  }
  async stop() {
    return new Promise((resolve) => {
      this.recorder?.addEventListener("stop", () => {
        resolve(this.flush());
      });
      this.recorder?.stop();
      void this.context?.suspend();
      for (const track of this.stream?.getTracks() ?? []) {
        track.stop();
      }
    });
  }
  async installWorklet(name, path, callback) {
    const context = this.getAudioContext();
    const stream = await this.getAudioStream();
    await context.audioWorklet.addModule(path);
    const node = new AudioWorkletNode(context, name);
    await callback({ context, stream, node });
  }
  on(eventName, callback) {
    if (!this.listeners[eventName]) {
      this.listeners[eventName] = [];
    }
    this.listeners[eventName]?.push(callback);
  }
  flush() {
    const blob = new Blob(this.buffer);
    this.buffer = [];
    return blob;
  }
  async createAudioRecorder() {
    const stream = await this.getAudioStream();
    const recorder = new MediaRecorder(stream, this.options);
    if ("volumechange" in this.listeners) {
      await this.setupAudioMeter();
    }
    recorder.addEventListener("dataavailable", ({ data }) => {
      if (data.size > 0) {
        this.buffer?.push(data);
      }
    });
    return recorder;
  }
  fireEvent(name, event) {
    for (const listener of this.listeners?.[name] ?? []) {
      listener(event);
    }
  }
  async getAudioStream() {
    if (!this.stream) {
      this.stream = await getUserMedia();
    }
    return this.stream;
  }
  getAudioContext() {
    if (!this.context) {
      this.context = new AudioContext();
    }
    return this.context;
  }
  getWorkletPath(name) {
    return [this.options.workletPath ?? "worklets", name].join("/");
  }
  async setupAudioMeter() {
    return this.installWorklet(
      "volume-meter",
      this.getWorkletPath("video-meter.js"),
      ({ node, context, stream }) => {
        const micNode = context.createMediaStreamSource(stream);
        node.port.addEventListener(
          "message",
          ({ data: volume }) => {
            this.fireEvent("volumechange", { volume });
          }
        );
        micNode.connect(node).connect(context.destination);
      }
    );
  }
}
export {
  AudioRecorder
};
//# sourceMappingURL=recorder.js.map
