import type { AudioEventListener, AudioEventListenerMap, AudioRecorderOptions, InstallWorkletVars } from "./types.js";
export declare class AudioRecorder {
    private readonly options;
    /**
     * Lists all of the users available audio devices
     * @returns The list of Device objects
     */
    static listDevices(): Promise<MediaDeviceInfo[]>;
    /**
     * The live audio context
     */
    private context?;
    /**
     * Dictionary of event listeners associated with the recorder
     */
    private listeners;
    /**
     * Buffer of currently recorded blob chunks
     */
    private buffer?;
    /**
     * Underlying media recorder object
     */
    private recorder?;
    /**
     * The currently active media stream
     */
    private stream?;
    constructor(options?: AudioRecorderOptions);
    /**
     * Starts recording audio using the given device ID or, if none is provided, the default device
     * @param deviceId Optional device ID to record with
     */
    start(deviceId?: string): Promise<void>;
    /**
     * Stops recording
     * @returns The recorded data as a Blob object
     */
    stop(): Promise<unknown>;
    /**
     * Installs a custom audio worklet to the current audio context
     *
     * @param name The registered name of the worklet
     * @param path The absolute path to the worklet
     * @param callback A registration callback containing the current audio context, audio stream, and worklet node
     */
    installWorklet(name: string, path: string, callback: (args: InstallWorkletVars) => void | Promise<void>): Promise<void>;
    /**
     * Attaches an event listener to the recorder
     * @param eventName The name of the event
     * @param callback The callback
     */
    on<T extends keyof AudioEventListenerMap>(eventName: T, callback: AudioEventListener<AudioEventListenerMap[T]>): void;
    /**
     * Clears the currently recorded chunks and returns the existing
     * chunks as a single blob object
     * @returns The recorded chunks as a single
     */
    private flush;
    /**
     * Initializes a new audio recorder with the correct event listeners attached
     * @param stream The MediaStream object for which to create the recorder
     * @param options Recorder options
     * @returns
     */
    private createAudioRecorder;
    /**
     * Triggers an event
     *
     * @param name Event name to trigger
     * @param event Event payload (if any)
     */
    private fireEvent;
    /**
     * Returns the active audio stream or creates one if one doesn't exist
     *
     * @returns The MediaStream object
     */
    private getAudioStream;
    /**
     * Returns the active audio context or creates one if one doesn't exist
     *
     * @returns The AudioContext object
     */
    private getAudioContext;
    /**
     * Resolves the path to the worklet with the specified name
     * using the global options
     *
     * @param name The filename of the worklet to resolve
     * @returns The absolute path to the worklet
     */
    private getWorkletPath;
    /**
     * Sets up audio metering if a volumechange listener is attached
     */
    private setupAudioMeter;
}
